aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/read_markers.h
diff options
context:
space:
mode:
authorAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
committerAndres Salomon <dilinger@queued.net>2021-01-18 04:00:14 -0500
commit09eb39236666e81d5da014acea011dcd74d0999b (patch)
tree52876d96be71be1a39d5d935c1295a51995e8949 /lib/csapi/read_markers.h
parentf1788ee27f33e9339334e0d79bde9a27d9ce2e44 (diff)
parenta4e78956f105875625b572d8b98459ffa86fafe5 (diff)
downloadlibquotient-09eb39236666e81d5da014acea011dcd74d0999b.tar.gz
libquotient-09eb39236666e81d5da014acea011dcd74d0999b.zip
Update upstream source from tag 'upstream/0.6.4'
Update to upstream version '0.6.4' with Debian dir aa8705fd74743e79c043bc9e3e425d5064404cfe
Diffstat (limited to 'lib/csapi/read_markers.h')
-rw-r--r--lib/csapi/read_markers.h50
1 files changed, 26 insertions, 24 deletions
diff --git a/lib/csapi/read_markers.h b/lib/csapi/read_markers.h
index d982b477..0e122c63 100644
--- a/lib/csapi/read_markers.h
+++ b/lib/csapi/read_markers.h
@@ -6,29 +6,31 @@
#include "jobs/basejob.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Set the position of the read marker for a room.
+ *
+ * Sets the position of the read marker for a given room, and optionally
+ * the read receipt's location.
+ */
+class SetReadMarkerJob : public BaseJob {
+public:
+ /*! \brief Set the position of the read marker for a room.
+ *
+ * \param roomId
+ * The room ID to set the read marker in for the user.
+ *
+ * \param mFullyRead
+ * The event ID the read marker should be located at. The
+ * event MUST belong to the room.
+ *
+ * \param mRead
+ * The event ID to set the read receipt location at. This is
+ * equivalent to calling ``/receipt/m.read/$elsewhere:example.org``
+ * and is provided here to save that extra call.
+ */
+ explicit SetReadMarkerJob(const QString& roomId, const QString& mFullyRead,
+ const QString& mRead = {});
+};
- /// Set the position of the read marker for a room.
- ///
- /// Sets the position of the read marker for a given room, and optionally
- /// the read receipt's location.
- class SetReadMarkerJob : public BaseJob
- {
- public:
- /*! Set the position of the read marker for a room.
- * \param roomId
- * The room ID to set the read marker in for the user.
- * \param mFullyRead
- * The event ID the read marker should be located at. The
- * event MUST belong to the room.
- * \param mRead
- * The event ID to set the read receipt location at. This is
- * equivalent to calling ``/receipt/m.read/$elsewhere:example.org``
- * and is provided here to save that extra call.
- */
- explicit SetReadMarkerJob(const QString& roomId, const QString& mFullyRead, const QString& mRead = {});
- };
-} // namespace QMatrixClient
+} // namespace Quotient